.. _spkg_colorama:

colorama: Cross-platform colored terminal text
==============================================

Description
-----------

Cross-platform colored terminal text

License
-------

Upstream Contact
----------------

https://pypi.org/project/colorama/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    0.4.6

version_requirements.txt::

    colorama

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install colorama

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i colorama

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-colorama


If the system package is installed, ``./configure`` will check if it can be used.
